ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder { /* private fields */ }
Builder for functional-style configuration.

Provides a chainable API for defining configuration options, similar to the JavaScript makeConfig API.

Example

use lino_arguments::make_config;

let config = make_config(|c| {
    c.lenv(".lenv")
     .option("port", "Server port", "3000")
     .option_short("api-key", 'k', "API key", "")
     .flag("verbose", "Enable verbose logging")
});

Implementations

Source

impl ConfigBuilder

pub fn name(&mut self, name: &str) -> &mut Self

Set the application name for help text.

pub fn about(&mut self, about: &str) -> &mut Self

Set the application description for help text.

pub fn version(&mut self, version: &str) -> &mut Self

Set the application version for –version flag.

pub fn lenv(&mut self, path: &str) -> &mut Self

Load a .lenv configuration file (without overriding existing env vars).

pub fn lenv_override(&mut self, path: &str) -> &mut Self

Load a .lenv configuration file, overriding existing env vars.

pub fn env(&mut self, path: &str) -> &mut Self

Load a .env configuration file (without overriding existing env vars).

pub fn env_override(&mut self, path: &str) -> &mut Self

Load a .env configuration file, overriding existing env vars.

pub fn option( &mut self, name: &str, description: &str, default: &str, ) -> &mut Self

Define a string/number option with a long name, description, and default value.

pub fn option_short( &mut self, name: &str, short: char, description: &str, default: &str, ) -> &mut Self

Define a string/number option with both short and long names.

pub fn flag(&mut self, name: &str, description: &str) -> &mut Self

Define a boolean flag (defaults to false).

pub fn flag_short( &mut self, name: &str, short: char, description: &str, ) -> &mut Self

Define a boolean flag with a short name.