pub struct Config { /* private fields */ }Expand description
Resolved configuration values from the functional API.
Contains all parsed configuration values accessible by key name. Values are stored as strings and can be retrieved with type conversion.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn get(&self, key: &str) -> String
pub fn get(&self, key: &str) -> String
Get a configuration value as a string. Returns empty string if the key is not found.
Sourcepub fn get_int(&self, key: &str, default: i64) -> i64
pub fn get_int(&self, key: &str, default: i64) -> i64
Get a configuration value as an integer. Returns the default if the key is not found or cannot be parsed.